@@ -1,8 +1,7 @@
 from upyog.imports import *
 from upyog.utils import *
 from upyog.os import *
-from upyog.cli import call_parse
-from upyog.cli import Param as P
+from upyog.cli import *
 from upyog.image import *
 
 logger.opt(colors=True)
